Module beamlit.models.get_trace_logs_response_200
=================================================

Classes
-------

`GetTraceLogsResponse200()`
:   Method generated by attrs for class GetTraceLogsResponse200.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :